# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`download_and_do`](#download_and_do): Create common directories and set defaults

**Defined types**

* [`download_and_do::extract_and_run`](#download_and_doextract_and_run): Download a file, extract it and then run a command.
* [`download_and_do::run`](#download_and_dorun): Download a file and then run it

## Classes

### download_and_do

Download_and_do base class to make download directories and for for setting default resource
parameters

Parameters on this class become defaults for download_and_do::run and
download_and_do::extract_and_run defined resource types.  See those classes
for a detailed explanation

#### Parameters

The following parameters are available in the `download_and_do` class.

##### `path`

Data type: `Variant[String, Array[String]]`

PATH variable to use when running commands (from module hiera data)

##### `base_dir`

Data type: `String`

Parent directory for downloaded files (from module hiera data)

##### `extract_dir`

Data type: `String`

Directory to extract archives in (from module hiera data)

##### `download_dir`

Data type: `String`

Directory to download files to (from module hiera data)

##### `provider`

Data type: `String`

Shell provider to use (from module hiera data)

##### `file_owner`

Data type: `String`

Owner for directory used to cache files

##### `file_group`

Data type: `Variant[Undef, String, Integer]`

Group for directory used to cache files

##### `path_separator`

Data type: `String`

Path separator character to use on this OS

##### `allow_insecure`

Data type: `Boolean`

Disable certificate validation (from module hiera data)

Default value: `false`

##### `file_mode`

Data type: `String`

Mode for directory used to cache files

Default value: "0755"

## Defined types

### download_and_do::extract_and_run

Perfect for things like downloadable tarballs containing RPMs to install.
The downloaded archive will be retained after running.  Use the checksum to force
a local update and reinstall

#### Examples

##### Download a tarball, extact it and run its install script

```puppet
download_and_do::extract_and_run { "test.tar.gz":
  source       => "http://files.megacorp.com/testcase/spec/mock/test.tar.gz",
  run_relative => "./install.sh",
  download_dir => "/usr/download",
  extract_dir  => "/usr/extract",
}
```

#### Parameters

The following parameters are available in the `download_and_do::extract_and_run` defined type.

##### `source`

Data type: `String`

Location to download archive from

##### `download_dir`

Data type: `String`

Directory to download archive to if not using module default

Default value: $download_and_do::download_dir

##### `local_file`

Data type: `String`

Where to save the file (inside $download_dir)

Default value: $title

##### `extract_dir`

Data type: `String`

Directory to extract archive to

Default value: $download_and_do::extract_dir

##### `checksum`

Data type: `Optional[String]`

Checksum of local archive file to see if update needed (SHA1)

Default value: `undef`

##### `run_relative`

Data type: `String`

Commands to run (relative to Extract dir) after downloading

##### `path`

Data type: `Variant[String, Array[String]]`

PATH (array) to use when running command after extraction

Default value: $download_and_do::path

##### `creates`

Data type: `Optional[String]`

Presence of this file indicates we do not need to download or
execute anything

Default value: `undef`

##### `unless`

Data type: `Optional[String]`

Pass-through parameter to exec to control whether to run or not

Default value: `undef`

##### `onlyif`

Data type: `Optional[String]`

Pass-through parameter to exec to control whether to run or not

Default value: `undef`

##### `user`

Data type: `Optional[String]`

User for file ownership and to run command with (not supported on windows)

Default value: `undef`

##### `group`

Data type: `Optional[String]`

Group for file ownership

Default value: `undef`

##### `environment`

Data type: `Optional[Variant[String, Array[String]]]`

Environment variables (BASH) to run command with

Default value: `undef`

##### `allow_insecure`

Data type: `Boolean`

Allow insecure HTTPS downloads

Default value: $download_and_do::allow_insecure

##### `provider`

Data type: `String`

Set the exec provider - needed as `cd` is a builtin. On windows you will need to set
`powershell` if you are attempting to download and execute powershell

Default value: $download_and_do::provider

##### `timeout`

Data type: `Optional[Integer]`

How long to wait before killing command we were told to run, in seconds.
Pass `0` to wait upto forever seconds for the command to complete

Default value: `undef`

##### `proxy_server`

Data type: `Optional[String]`

specify a proxy server, with port number if needed. ie: https://example.com:8080.

Default value: `undef`

##### `proxy_type`

Data type: `Optional[String]`

proxy server type (none|http|https|ftp)

Default value: `undef`

##### `cleanup`

Data type: `Boolean`

Remove extracted archive after download?

Default value: `true`

##### `path_separator`

Data type: `String`

Path separator character to use on this OS

Default value: $download_and_do::path_separator

### download_and_do::run

Perfect for things like self-installing bash scripts.  The script will be
retained after running.  Use the checksum to force a local update and reinstall

#### Examples

##### Download a test script and run it

```puppet
download_and_do::run { "test2.sh":
  source => "http://files.megacorp.com/testcase/spec/mock/test2.sh",
}
```

#### Parameters

The following parameters are available in the `download_and_do::run` defined type.

##### `source`

Data type: `String`

File to download

##### `local_file`

Data type: `String`

Where to save the file (inside $download_dir)

Default value: $title

##### `download_dir`

Data type: `String`

Drectory to download to instead of module default

Default value: $download_and_do::download_dir

##### `path`

Data type: `Variant[String, Array[String]]`

PATH to use for executing file

Default value: $download_and_do::path

##### `checksum`

Data type: `Optional[String]`

Checksum (SHA1) of file, used to detect updates

Default value: `undef`

##### `creates`

Data type: `Optional[String]`

Presence of this file indicates we do not need to download or
execute anything

Default value: `undef`

##### `unless`

Data type: `Optional[String]`

Pass-through parameter to exec to control whether to run or not

Default value: `undef`

##### `onlyif`

Data type: `Optional[String]`

Pass-through parameter to exec to control whether to run or not

Default value: `undef`

##### `user`

Data type: `Optional[String]`

User for file ownership and to run command (not supported on windows)

Default value: `undef`

##### `group`

Data type: `Optional[String]`

Group for file ownership

Default value: `undef`

##### `environment`

Data type: `Optional[Variant[String, Array[String]]]`

Environment variables (BASH) to run command with

Default value: `undef`

##### `arguments`

Data type: `String`

Arguments to pass to the downloaded file to be run

Default value: ""

##### `allow_insecure`

Data type: `Boolean`

Allow insecure HTTPS downloads

Default value: $download_and_do::allow_insecure

##### `provider`

Data type: `String`

Set the exec provider - needed as `cd` is a builtin. On windows you will need to set
`powershell` if you are attempting to download and execute powershell

Default value: $download_and_do::provider

##### `timeout`

Data type: `Optional[Integer]`

How long to wait before killing command we were told to run, in seconds.
Pass `0` to wait upto forever seconds for the command to complete

Default value: `undef`

##### `proxy_server`

Data type: `Optional[String]`

specify a proxy server, with port number if needed. ie: https://example.com:8080.

Default value: `undef`

##### `proxy_type`

Data type: `Optional[String]`

proxy server type (none|http|https|ftp)

Default value: `undef`

##### `path_separator`

Data type: `String`

Path separator character to use on this OS

Default value: $download_and_do::path_separator

